/** @jsx jsx */
import { useCallback } from 'react';
import { css, jsx } from '@emotion/react';
import classnames from 'classnames';
import { N0, N30, N40, N500 } from '@atlaskit/theme/colors';
var labelStyles = css({
  opacity: 0,
  display: 'inline-flex',
  width: 'max-content',
  justifyContent: 'left',
  position: 'absolute',
  // Unfortunately, these need to be these exact numbers - otherwise there will be a noticeable gap/overlap
  // eslint-disable-next-line @atlaskit/design-system/ensure-design-token-usage/preview
  top: '-19px',
  '&.inline': {
    // eslint-disable-next-line @atlaskit/design-system/ensure-design-token-usage/preview
    top: '-18px',
    marginLeft: "var(--ds-space-150, 12px)"
  },
  '&.show-label': {
    cursor: 'pointer',
    background: "var(--ds-background-accent-gray-subtle-pressed, ".concat(N40, ")"),
    color: "var(--ds-text-subtle, ".concat(N500, ")"),
    opacity: 1
  },
  borderRadius: "var(--ds-border-radius, 3px)".concat(" ", "var(--ds-border-radius, 3px)", " 0 0"),
  lineHeight: 1,
  '&.nested': {
    // Need to add indent if the node is nested since we removed previous indentation styles to make it fit properly
    // in the nested component
    marginLeft: "var(--ds-space-150, 12px)"
  },
  '&.bodied-background': {
    background: "var(--ds-surface, ".concat(N0, ")")
  },
  '&.bodied-border': {
    border: "1px solid ".concat("var(--ds-border, ".concat(N30, ")"))
  },
  // to account for bodied having borders now - adding this to help with less conditional styling
  border: '1px solid transparent',
  borderBottom: 'none'
});
var textStyles = css({
  fontSize: '14px',
  fontWeight: 'normal',
  padding: "var(--ds-space-025, 2px)".concat(" ", "var(--ds-space-050, 4px)")
});
var containerStyles = css({
  textAlign: 'left',
  zIndex: 1,
  position: 'relative',
  '&.bodied': {
    marginTop: "var(--ds-space-300, 24px)"
  }
});
export var ExtensionLabel = function ExtensionLabel(_ref) {
  var text = _ref.text,
    extensionName = _ref.extensionName,
    isNodeHovered = _ref.isNodeHovered,
    customContainerStyles = _ref.customContainerStyles,
    isNodeNested = _ref.isNodeNested,
    setIsNodeHovered = _ref.setIsNodeHovered,
    isBodiedMacro = _ref.isBodiedMacro;
  var containerClassNames = classnames({
    bodied: isBodiedMacro
  });
  var labelClassNames = classnames('extension-label', {
    nested: isNodeNested,
    inline: extensionName === 'inlineExtension',
    bodied: isBodiedMacro,
    'bodied-border': isBodiedMacro && !isNodeHovered,
    'bodied-background': isBodiedMacro && !isNodeHovered,
    'show-label': isNodeHovered || isBodiedMacro
  });
  var handleMouseEnter = useCallback(function () {
    // If current node is hovered and the label is hovered,
    // consider the node as hovered so we can display the label for users to click on
    if (isNodeHovered) {
      setIsNodeHovered === null || setIsNodeHovered === void 0 || setIsNodeHovered(true);
    }
  }, [isNodeHovered, setIsNodeHovered]);
  var handleMouseLeave = useCallback(function () {
    setIsNodeHovered === null || setIsNodeHovered === void 0 || setIsNodeHovered(false);
  }, [setIsNodeHovered]);
  return jsx("div", {
    css: containerStyles,
    className: containerClassNames,
    style: customContainerStyles,
    onMouseEnter: handleMouseEnter,
    onMouseLeave: handleMouseLeave,
    "data-testid": "new-lozenge-container"
  }, jsx("span", {
    "data-testid": "new-lozenge",
    css: labelStyles,
    className: labelClassNames
  }, jsx("span", {
    css: textStyles
  }, text)));
};